<?php
/*
Plugin Name: Genesis merce
Plugin URI: http://badlywired.com
Description: Make Genesis theme WooCommerce compatible
Version: 1.0
Author: Alan Fuller
Author URI: https://badlywired.com/author/alan/
License: GPLv2 or later
*/
/**
 * Check if WooCommerce is active
 **/
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {


  /**********************************
  *
  * Integrate WooCommerce with Genesis.
  *
  * Unhook WooCommerce wrappers and
  * Replace with Genesis wrappers.
  *
  * Reference Genesis file:
  * genesis/lib/framework.php
  *
  * @author AlphaBlossom / Tony Eppright
  * @link http://www.alphablossom.com
  *
  **********************************/


  // Remove WooCommerce Theme Support admin message
  add_theme_support( 'woocommerce' );

  // Remove Genesis breadcrumbs, using Woocommerce crumbs instead.
  add_action( 'get_header', 'youruniqueprefix_remove_wc_breadcrumbs' );
  function youruniqueprefix_remove_wc_breadcrumbs() {

    remove_action( 'genesis_before_loop', 'genesis_do_breadcrumbs' );

}




  // Add WooCommerce support for Genesis layouts (sidebar, full-width, etc) - Thank you Kelly Murray
  add_post_type_support( 'product', 'genesis-layouts' );

  // Unhook WooCommerce Sidebar - use Genesis Sidebars instead
  remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );

  // Unhook WooCommerce wrappers
  remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
  remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

  // Hook new functions with Genesis wrappers
  add_action( 'woocommerce_before_main_content', 'youruniqueprefix_my_theme_wrapper_start', 10 );
  add_action( 'woocommerce_after_main_content', 'youruniqueprefix_my_theme_wrapper_end', 10 );

  // Add opening wrapper before WooCommerce loop
  function youruniqueprefix_my_theme_wrapper_start() {

    do_action( 'genesis_before_content_sidebar_wrap' );
    genesis_markup( array(
        'html5' => '<div %s>',
        'xhtml' => '<div id="content-sidebar-wrap">',
        'context' => 'content-sidebar-wrap',
    ) );

    do_action( 'genesis_before_content' );
    genesis_markup( array(
        'html5' => '<main %s>',
        'xhtml' => '<div id="content" class="hfeed">',
        'context' => 'content',
    ) );
    do_action( 'genesis_before_loop' );

  }

  /* Add closing wrapper after WooCommerce loop */
  function youruniqueprefix_my_theme_wrapper_end() {

    do_action( 'genesis_after_loop' );
    genesis_markup( array(
        'html5' => '</main>', //* end .content
        'xhtml' => '</div>', //* end #content
    ) );
    do_action( 'genesis_after_content' );

    echo '</div>'; //* end .content-sidebar-wrap or #content-sidebar-wrap
    do_action( 'genesis_after_content_sidebar_wrap' );

  }

}
